/*
  BV518
*/
#define BRATE 115200
#include <SoftwareSerial.h>
const byte rxPin = 2;
const byte txPin = 3;

SoftwareSerial sws(rxPin,txPin);

void setup() {
  // put your setup code here, to run once:
  pinMode(rxPin,INPUT);
  pinMode(txPin,OUTPUT);
  sws.begin(BRATE);
}

// ----------------------------------------------------------
// Some serial utilities
// **********************************************************
// makes sure nothing is in the serial buffer
// **********************************************************
void serial_clear() {
  while(sws.available())
    sws.read();
}

// **********************************************************
// Utility for sending commands and waiting for the 
// > prompt, can check return value error if 0
// **********************************************************
char send_cmd(const char *cmd) {
  char tmp[80];
  serial_clear();
  sws.println(cmd);
  sws.flush(); // just in case
  return sws.readBytesUntil('>',tmp,75);
}

// **********************************************************
// Utility to send the faPut command that can use varing
// parameters
// **********************************************************
void send_faPut(int row, int col, char *data) {
  char buf[80];
  sprintf(buf,"faPut(%d,%d,\"%s\")",row,col,data);
  send_cmd(buf);
}

// **********************************************************
// creating a spreadsheet of sensor information
// **********************************************************
void loop() {
  char row,col;
  
  send_cmd(""); // always send a blank line first

  // create a new 2 dimentional array for sensor information
  // faNew will destroy any existing file, use faUse to add or modify
  // an existing file
  send_cmd("faNew(5,80,\"sens1.txt\")");

  // set up columns
  send_faPut(0,0,"Date");
  send_faPut(0,1,"Sensor 1");
  send_faPut(0,2,"Sensor 2");
  send_faPut(0,3,"Sensor 3");
  send_faPut(0,4,"Sensor 4");

  // send fictional data as an example
  for(row=1;row<5;row++) {
      // send_cmd("faPut(row,0,\"Sensor 4\")")
      send_faPut(row,0,"12 Nov 2005"); // first date col
      for(col=1;col<5;col++) {
        send_faPut(row,col,"data");
      }
  }
  // convert file to spreadsheet
  send_cmd("fConvert(\"sens1.txt\",\"sens.csv\")");
  while(1); // halt
}

